# roomor: A framework for autogenerating and deploying random room simulation for Gazebo

[![MIT License](https://img.shields.io/badge/license-MIT-green)](https://github.com/wwwshwww/roomor/blob/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/roomor)](https://pypi.org/project/roomor/)
![PyPI - Python Version](https://shields.io/pypi/pyversions/roomor)

## Installation

Install using pip:

```bash
pip install roomor
```

If using python2.7, install numpy-quaternion below version before run above command.

```bash
pip install numpy-quaternion==2019.12.11.22.25.52
```

## Implemented generator

 `CubeRoomGenerator`

<img src='https://user-images.githubusercontent.com/41321650/121756680-f059ae80-cb55-11eb-92ac-95700c779590.png' width=50%>
<img src='https://user-images.githubusercontent.com/41321650/121756698-fbacda00-cb55-11eb-939f-fc542fae5e51.png' width=50%>

## Usage

See example ipynb in `example/`.
